import { Subject } from 'rxjs';
import { PickupGridViewBase } from '@/studio-core';
import HROMHierarchyCatService from '@/service/hromhierarchy-cat/hromhierarchy-cat-service';
import HROMHierarchyCatAuthService from '@/authservice/hromhierarchy-cat/hromhierarchy-cat-auth-service';
import PickupGridViewEngine from '@engine/view/pickup-grid-view-engine';
import HROMHierarchyCatUIService from '@/uiservice/hromhierarchy-cat/hromhierarchy-cat-ui-service';

/**
 * 结构层次类别选择表格视图视图基类
 *
 * @export
 * @class HROMHierarchyCatPickupGridViewBase
 * @extends {PickupGridViewBase}
 */
export class HROMHierarchyCatPickupGridViewBase extends PickupGridViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    protected appDeName: string = 'hromhierarchycat';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    protected appDeKey: string = 'omhierarchycatid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    protected appDeMajor: string = 'omhierarchycatname';

    /**
     * 实体服务对象
     *
     * @type {HROMHierarchyCatService}
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    protected appEntityService: HROMHierarchyCatService = new HROMHierarchyCatService;

    /**
     * 实体权限服务对象
     *
     * @type HROMHierarchyCatUIService
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public appUIService: HROMHierarchyCatUIService = new HROMHierarchyCatUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HROMHierarchyCatPickupGridViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    protected model: any = {
        srfCaption: 'entities.hromhierarchycat.views.pickupgridview.caption',
        srfTitle: 'entities.hromhierarchycat.views.pickupgridview.title',
        srfSubTitle: 'entities.hromhierarchycat.views.pickupgridview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
        view_searchform: { name: 'searchform', type: 'SEARCHFORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '045cc74f78937b52db67b8239361d181';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public engine: PickupGridViewEngine = new PickupGridViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            grid: this.$refs.grid,
            searchform: this.$refs.searchform,
            keyPSDEField: 'hromhierarchycat',
            majorPSDEField: 'omhierarchycatname',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * searchform 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public searchform_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'save', $event);
    }

    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public searchform_search($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }

    /**
     * searchform 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    public searchform_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'load', $event);
    }



    /**
     * 是否展开搜索表单
     *
     * @protected
     * @type {boolean}
     * @memberof HROMHierarchyCatPickupGridViewBase
     */
    protected isExpandSearchForm: boolean = true;


}